from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Array, String, Boolean, File, Directory, Int

Bioconda_Utils_Build_V0_1_0 = CommandToolBuilder(tool="bioconda_utils_build", base_command=["bioconda-utils", "build"], inputs=[ToolInput(tag="in_packages", input_type=Array(t=String(), optional=True), prefix="--packages", doc=InputDocumentation(doc="Glob for package[s] to build. Default is to build all\npackages. Can be specified more than once (default:\n'*')")), ToolInput(tag="in_git_range", input_type=Array(t=String(), optional=True), prefix="--git-range", doc=InputDocumentation(doc="Git range (e.g. commits or something like 'master\nHEAD' to check commits in HEAD vs master, or just\n'HEAD' to include uncommitted changes). All recipes\nmodified within this range will be built if not\npresent in the channel. (default: -)")), ToolInput(tag="in_test_only", input_type=Boolean(optional=True), prefix="--testonly", doc=InputDocumentation(doc="Test packages instead of building (default: False)")), ToolInput(tag="in_force", input_type=Boolean(optional=True), prefix="--force", doc=InputDocumentation(doc="Force building the recipe even if it already exists in\nthe bioconda channel. If --force is specified, --git-\nrange is ignored and only those packages matching\n--packages globs will be built. (default: False)")), ToolInput(tag="in_docker", input_type=Boolean(optional=True), prefix="--docker", doc=InputDocumentation(doc="Build packages in docker container. (default: -)")), ToolInput(tag="in_mulled_test", input_type=Boolean(optional=True), prefix="--mulled-test", doc=InputDocumentation(doc="Run a mulled-build test on the built package (default:\nFalse)")), ToolInput(tag="in_build_script_template", input_type=File(optional=True), prefix="--build_script_template", doc=InputDocumentation(doc="Filename to optionally replace build script template\nused by the Docker container. By default use\ndocker_utils.BUILD_SCRIPT_TEMPLATE. Only used if\n--docker is True. (default: -)")), ToolInput(tag="in_pkg_dir", input_type=Directory(optional=True), prefix="--pkg_dir", doc=InputDocumentation(doc="Specifies the directory to which container-built\npackages should be stored on the host. Default is to\nuse the host's conda-bld dir. If --docker is not\nspecified, then this argument is ignored. (default: -)")), ToolInput(tag="in_anaconda_upload", input_type=Boolean(optional=True), prefix="--anaconda-upload", doc=InputDocumentation(doc="After building recipes, upload them to Anaconda. This\nrequires $ANACONDA_TOKEN to be set. (default: False)")), ToolInput(tag="in_mulled_upload_target", input_type=String(optional=True), prefix="--mulled-upload-target", doc=InputDocumentation(doc="Provide a quay.io target to push mulled docker images\nto. (default: -)")), ToolInput(tag="in_build_image", input_type=Boolean(optional=True), prefix="--build-image", doc=InputDocumentation(doc="Build temporary docker build image with conda/conda-\nbuild version matching local versions (default: False)")), ToolInput(tag="in_keep_image", input_type=Boolean(optional=True), prefix="--keep-image", doc=InputDocumentation(doc="After building recipes, the created Docker image is\nremoved by default to save disk space. Use this\nargument to disable this behavior. (default: False)")), ToolInput(tag="in_pre_lint", input_type=Boolean(optional=True), prefix="--prelint", doc=InputDocumentation(doc="Just before each recipe, apply the linting functions\nto it. This can be used as an alternative to linting\nall recipes before any building takes place with the\n`bioconda-utils lint` command. (default: False)")), ToolInput(tag="in_lint_exclude", input_type=Array(t=String(), optional=True), prefix="--lint-exclude", doc=InputDocumentation(doc="Exclude this linting function. Can be used multiple\ntimes. (default: -)")), ToolInput(tag="in_check_channels", input_type=Array(t=String(), optional=True), prefix="--check-channels", doc=InputDocumentation(doc="Channels to check recipes against before building. Any\nrecipe already present in one of these channels will\nbe skipped. The default is the first two channels\nspecified in the config file. Note that this is\nignored if you specify --git-range. (default: -)")), ToolInput(tag="in_n_workers", input_type=Int(optional=True), prefix="--n-workers", doc=InputDocumentation(doc="The number of parallel workers that are in use. This\nis intended for use in cases such as the 'bulk'\nbranch, where there are multiple parallel workers\nbuilding and uploading recipes. In essence, this\ncauses bioconda-utils to process every Nth sub-DAG,\nwhere N is the value you give to this option. The\ndefault is 1, which is intended for cases where there\nare NOT parallel workers (i.e., the majority of\ncases). This should generally NOT be used in\nconjunctions with the --packages or --git-range\noptions! (default: 1)")), ToolInput(tag="in_worker_offset", input_type=Int(optional=True), prefix="--worker-offset", doc=InputDocumentation(doc="This is only used if --nWorkers is >1. In that case,\nthen each instance of bioconda-utils will process\nevery Nth sub-DAG. This option gives the 0-based\noffset for that. For example, if '--n-workers 5\n--worker-offset 0' is used, then this instance of\nbioconda-utils will process the 1st, 6th, 11th, etc.\nsub-DAGs. Equivalently, using '--n-workers 5 --worker-\noffset 1' will result in sub-DAGs 2, 7, 12, etc. being\nprocessed. If you use more than one worker, then make\nsure to give each a different offset! (default: 0)")), ToolInput(tag="in_keep_old_work", input_type=Boolean(optional=True), prefix="--keep-old-work", doc=InputDocumentation(doc="Do not remove anything from environment, even after\nsuccessful build and test. (default: False)")), ToolInput(tag="in_loglevel", input_type=String(optional=True), prefix="--loglevel", doc=InputDocumentation(doc="Set logging level (debug, info, warning, error,\ncritical) (default: 'info')")), ToolInput(tag="in_log_file", input_type=File(optional=True), prefix="--logfile", doc=InputDocumentation(doc="Write log to file (default: -)")), ToolInput(tag="in_log_file_level", input_type=File(optional=True), prefix="--logfile-level", doc=InputDocumentation(doc="Log level for log file (default: 'debug')")), ToolInput(tag="in_log_command_max_lines", input_type=Int(optional=True), prefix="--log-command-max-lines", doc=InputDocumentation(doc="Limit lines emitted for commands executed (default: -)\n")), ToolInput(tag="in_recipe_folder", input_type=String(), position=0, doc=InputDocumentation(doc="Path to folder containing recipes (default: recipes/)\n(default: -)")), ToolInput(tag="in_config", input_type=String(), position=1, doc=InputDocumentation(doc="Path to Bioconda config (default: config.yml)\n(default: -)"))], outputs=[], container="quay.io/biocontainers/bioconda-utils:0.16.23--py_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Bioconda_Utils_Build_V0_1_0().translate("wdl")

